searchData={"items":[{"type":"module","title":"Tzdata","doc":"The Tzdata module provides data from the IANA tz database. Also known\nas the Olson/Eggert database, zoneinfo, tzdata and other names.\n\nA list of time zone names (e.g. `America/Los_Angeles`) are provided.\nAs well as functions for finding out the UTC offset, abbreviation,\nstandard offset (DST) for a specific point in time in a certain\ntimezone.","ref":"Tzdata.html"},{"type":"function","title":"Tzdata.canonical_zone?/1","doc":"Takes the name of a zone. Returns true if zone exists and is canonical.\nOtherwise false.\n\n    iex> Tzdata.canonical_zone? \"Europe/London\"\n    true\n    iex> Tzdata.canonical_zone? \"Europe/Jersey\"\n    false","ref":"Tzdata.html#canonical_zone?/1"},{"type":"function","title":"Tzdata.canonical_zone_list/0","doc":"Like zone_list, but excludes aliases for zones.","ref":"Tzdata.html#canonical_zone_list/0"},{"type":"type","title":"Tzdata.gregorian_seconds/0","doc":"","ref":"Tzdata.html#t:gregorian_seconds/0"},{"type":"function","title":"Tzdata.leap_second_data_valid_until/0","doc":"The time when the leap second information returned from the other leap second\nrelated function expires. The date-time is in UTC.","ref":"Tzdata.html#leap_second_data_valid_until/0"},{"type":"function","title":"Example - Tzdata.leap_second_data_valid_until/0","doc":"Tzdata.leap_second_data_valid_until\n    {{2015, 12, 28}, {0, 0, 0}}","ref":"Tzdata.html#leap_second_data_valid_until/0-example"},{"type":"function","title":"Tzdata.leap_seconds/0","doc":"Get a list of known leap seconds. The leap seconds are datetime\ntuples representing the extra leap second to be inserted.\nThe date-times are in UTC.\n\nSee also `leap_seconds_with_tai_diff/1`","ref":"Tzdata.html#leap_seconds/0"},{"type":"function","title":"Example - Tzdata.leap_seconds/0","doc":"iex> Tzdata.leap_seconds() |> Enum.take(2)\n    [{{1972,  6, 30}, {23, 59, 60}},\n     {{1972, 12, 31}, {23, 59, 60}}]","ref":"Tzdata.html#leap_seconds/0-example"},{"type":"function","title":"Tzdata.leap_seconds_with_tai_diff/0","doc":"Get a list of maps with known leap seconds and\nthe difference between UTC and the TAI in seconds.\n\nSee also `leap_seconds/1`","ref":"Tzdata.html#leap_seconds_with_tai_diff/0"},{"type":"function","title":"Example - Tzdata.leap_seconds_with_tai_diff/0","doc":"iex> Tzdata.leap_seconds_with_tai_diff() |> Enum.take(2)\n    [%{date_time: {{1972,  6, 30}, {23, 59, 60}}, tai_diff: 11},\n     %{date_time: {{1972, 12, 31}, {23, 59, 60}}, tai_diff: 12}]","ref":"Tzdata.html#leap_seconds_with_tai_diff/0-example"},{"type":"function","title":"Tzdata.links/0","doc":"Returns a map of links. Also known as aliases.\n\n    iex> Tzdata.links()[\"Europe/Jersey\"]\n    \"Europe/London\"","ref":"Tzdata.html#links/0"},{"type":"function","title":"Tzdata.periods/1","doc":"Returns a list of periods for the `zone_name` provided as an argument.\n\nA period in this case is a period of time where the UTC offset and standard\noffset are in a certain way. When they change, for instance in spring when\nDST takes effect, a new period starts. For instance a period can begin in\nspring when winter time ends and summer time begins. The period lasts until\nDST ends.\n\nIf either the UTC or standard offset change for any reason, a new period\nbegins. For instance instead of DST ending or beginning, a rule change\nthat changes the UTC offset will also mean a new period.\n\nThe result is tagged with :ok if the zone_name is correct.\n\nThe from and until times can be :mix, :max or gregorian seconds.","ref":"Tzdata.html#periods/1"},{"type":"function","title":"Example - Tzdata.periods/1","doc":"iex> Tzdata.periods(\"Europe/Madrid\") |> elem(1) |> Enum.take(1)\n    [%{from: %{standard: :min, utc: :min, wall: :min}, std_off: 0,\n      until: %{standard: 59989763760, utc: 59989764644, wall: 59989763760},\n      utc_off: -884, zone_abbr: \"LMT\"}]\n    iex> Tzdata.periods(\"Not existing\")\n    {:error, :not_found}","ref":"Tzdata.html#periods/1-example"},{"type":"function","title":"Tzdata.periods_for_time/3","doc":"Get the periods that cover a certain point in time. Usually it will be a list\nwith just one period. But in some cases it will be zero or two periods. For\ninstance when going from summer to winter time (DST to standard time) there\nwill be an overlap if `time_type` is `:wall`.\n\n`zone_name` should be a valid time zone name. The function `zone_list/0`\nprovides a valid list of valid zone names.\n\n`time_point` is the point in time in gregorian seconds (see erlang\ncalendar module documentation for more info on gregorian seconds).\n\nValid values for `time_type` is `:utc`, `:wall` or `:standard`.","ref":"Tzdata.html#periods_for_time/3"},{"type":"function","title":"Examples - Tzdata.periods_for_time/3","doc":"# 63555753600 seconds is equivalent to {{2015, 1, 1}, {0, 0, 0}}\n    iex> Tzdata.periods_for_time(\"Asia/Tokyo\", 63587289600, :wall)\n    [%{from: %{standard: 61589289600, utc: 61589257200, wall: 61589289600}, std_off: 0,\n      until: %{standard: :max, utc: :max, wall: :max}, utc_off: 32400, zone_abbr: \"JST\"}]\n\n    # 63612960000 seconds is equivalent to 2015-10-25 02:40:00 and is an ambiguous\n    # wall time for the zone. So two possible periods will be returned.\n    iex> Tzdata.periods_for_time(\"Europe/Copenhagen\", 63612960000, :wall)\n    [%{from: %{standard: 63594813600, utc: 63594810000, wall: 63594817200}, std_off: 3600,\n            until: %{standard: 63612957600, utc: 63612954000, wall: 63612961200}, utc_off: 3600, zone_abbr: \"CEST\"},\n          %{from: %{standard: 63612957600, utc: 63612954000, wall: 63612957600}, std_off: 0,\n            until: %{standard: 63626263200, utc: 63626259600, wall: 63626263200}, utc_off: 3600, zone_abbr: \"CET\"}]\n\n    # 63594816000 seconds is equivalent to 2015-03-29 02:40:00 and is a\n    # non-existing wall time for the zone. It is spring and the clock skips that hour.\n    iex> Tzdata.periods_for_time(\"Europe/Copenhagen\", 63594816000, :wall)\n    []","ref":"Tzdata.html#periods_for_time/3-examples"},{"type":"type","title":"Tzdata.time_zone_period/0","doc":"","ref":"Tzdata.html#t:time_zone_period/0"},{"type":"type","title":"Tzdata.time_zone_period_limit/0","doc":"","ref":"Tzdata.html#t:time_zone_period_limit/0"},{"type":"function","title":"Tzdata.tzdata_version/0","doc":"Returns tzdata release version as a string.\n\nExample:\n\n    Tzdata.tzdata_version\n    \"2014i\"","ref":"Tzdata.html#tzdata_version/0"},{"type":"function","title":"Tzdata.zone_alias?/1","doc":"Takes the name of a zone. Returns true if zone exists and is an alias.\nOtherwise false.\n\n    iex> Tzdata.zone_alias? \"Europe/Jersey\"\n    true\n    iex> Tzdata.zone_alias? \"Europe/London\"\n    false","ref":"Tzdata.html#zone_alias?/1"},{"type":"function","title":"Tzdata.zone_alias_list/0","doc":"A list of aliases for zone names. For instance Europe/Jersey\nis an alias for Europe/London. Aliases are also known as linked zones.","ref":"Tzdata.html#zone_alias_list/0"},{"type":"function","title":"Tzdata.zone_exists?/1","doc":"Takes the name of a zone. Returns true if zone exists. Otherwise false.\n\n    iex> Tzdata.zone_exists? \"Pacific/Auckland\"\n    true\n    iex> Tzdata.zone_exists? \"America/Sao_Paulo\"\n    true\n    iex> Tzdata.zone_exists? \"Europe/Jersey\"\n    true","ref":"Tzdata.html#zone_exists?/1"},{"type":"function","title":"Tzdata.zone_list/0","doc":"zone_list provides a list of all the zone names that can be used with\nDateTime. This includes aliases.","ref":"Tzdata.html#zone_list/0"},{"type":"function","title":"Tzdata.zone_lists_grouped/0","doc":"Returns a map with keys being group names and the values lists of\ntime zone names. The group names mirror the file names used by the tzinfo\ndatabase.","ref":"Tzdata.html#zone_lists_grouped/0"},{"type":"module","title":"Tzdata.TimeZoneDatabase","doc":"Module for interfacing with the standard library time zone related functions of Elixir 1.8+.\n\nImplements the `Calendar.TimeZoneDatabase` behaviour.","ref":"Tzdata.TimeZoneDatabase.html"},{"type":"extras","title":"Tzdata","doc":"Tzdata\n======\n\n[![Build\nStatus](https://travis-ci.org/lau/tzdata.svg?branch=master)](https://travis-ci.org/lau/tzdata)\n[![Hex.pm version](https://img.shields.io/hexpm/v/tzdata.svg)](http://hex.pm/packages/tzdata)\n[![Hex.pm downloads](https://img.shields.io/hexpm/dt/tzdata.svg)](https://hex.pm/packages/tzdata)\n\nTzdata. The [timezone database](https://www.iana.org/time-zones) in Elixir.\n\nExtracted from the [Calendar](https://github.com/lau/calendar) library.\n\nAs of version 1.1.3 the tz release 2025a is included in the package.\n\nWhen a new release is out, it will be automatically downloaded at runtime.\n\nThe tz release version in use can be verified with the following function:\n\n```elixir\niex> Tzdata.tzdata_version\n\"2024b\"\n```","ref":"readme.html"},{"type":"extras","title":"Getting started - Tzdata","doc":"To use the Tzdata library with Elixir 1.8+, add it to the dependencies in your mix file:\n\n```elixir\ndefp deps do\n  [  {:tzdata, \"~> 1.1\"},  ]\nend\n```\n\nIn your application you can choose to globally configure Elixir to use Tzdata.\nThis can be done by putting the following line in the config file of your application:\n\n    config :elixir, :time_zone_database, Tzdata.TimeZoneDatabase\n\nThat's it!\n\nThat allows you to [use the Elixir standard library to use Tzdata to do time zone calculations](https://hexdocs.pm/elixir/DateTime.html#content).\nOne example is getting the current time in a certain time zone:\n\n```elixir\niex> DateTime.now(\"Europe/Copenhagen\")\n{:ok, #DateTime<2018-11-30 20:51:59.076524+01:00 CET Europe/Copenhagen>}\n```\n\nIf you do not want Elixir to have a time zone database globally defined you can instead pass\nthe module name `Tzdata.TimeZoneDatabase` directly to the functions that need a time zone database:\n\n```elixir\nDateTime.now(\"Europe/Copenhagen\", Tzdata.TimeZoneDatabase)\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"Data directory and releases - Tzdata","doc":"The library uses a file directory to store data. By default this directory\nis `priv`. In some cases you might want to use a different directory. For\ninstance when using releases this is recommended. If so, create the directory and\nmake sure Elixir can read and write to it. Then use elixir config files like this\nto tell Tzdata to use that directory:\n\n```elixir\nconfig :tzdata, :data_dir, \"/etc/elixir_tzdata_data\"\n```\n\nAdd the `release_ets` directory from `priv` to that directory\ncontaining the `20xxx.ets` file that ships with this library.\n\nFor instance with this config: `config :tzdata, :data_dir, \"/etc/elixir_tzdata_data\"`\nan `.ets` file such as `/etc/elixir_tzdata_data/release_ets/2017b.ets` should be present.","ref":"readme.html#data-directory-and-releases"},{"type":"extras","title":"Automatic data updates - Tzdata","doc":"By default Tzdata will poll for timezone database updates every day.\nIn case new data is available, Tzdata will download it and use it.\n\nThis feature can be disabled with the following configuration:\n\n```elixir\nconfig :tzdata, :autoupdate, :disabled\n```\n\nIf the autoupdate setting is set to disabled, one has to manually put updated .ets files\nin the release_ets sub-dir of the \"data_dir\" (see the \"Data directory and releases\" section above).\nWhen IANA releases new versions of the time zone data, this Tzdata library can be used to generate\na new .ets file containing the new data.","ref":"readme.html#automatic-data-updates"},{"type":"extras","title":"Changes from 0.1.x to 0.5.x - Tzdata","doc":"The 0.5.1+ versions uses ETS tables and automatically polls the IANA\nservers for updated data. When a new version of the timezone database\nis available, it is automatically downloaded and used.\n\nFor use with [Calendar](https://github.com/lau/calendar) you can still\nspecify tzdata ~> 0.1.7 in your mix.exs file in case you experience problems\nusing version ~> 0.5.20","ref":"readme.html#changes-from-0-1-x-to-0-5-x"},{"type":"extras","title":"Hackney dependency and security - Tzdata","doc":"Tzdata depends on Hackney in order to do HTTPS requests to get new updates. This is done because Erlang's built in HTTP client `httpc` does not verify SSL certificates when doing HTTPS requests. Hackney verifies the certificate of IANA when getting new tzdata releases from IANA.","ref":"readme.html#hackney-dependency-and-security"},{"type":"extras","title":"Documentation - Tzdata","doc":"Documentation can be found at http://hexdocs.pm/tzdata/","ref":"readme.html#documentation"},{"type":"extras","title":"When new timezone data is released - Tzdata","doc":"IANA releases new versions of the [timezone database](https://www.iana.org/time-zones) frequently.\n\nFor users of Tzdata version 0.5.x+ the new database will automatically\nbe downloaded, parsed, saved and used in place of the old data.","ref":"readme.html#when-new-timezone-data-is-released"},{"type":"extras","title":"License - Tzdata","doc":"The tzdata Elixir library is released under the MIT license. See the LICENSE file.\n\nThe tz database files (found in the source_data directory of early versions) is public domain.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}